@@ -24,7 +24,7 @@
 # Written by Peter J Billam, http://www.pjb.com.au
 
 package Crypt::Tea_JS;
-$VERSION = '2.21';
+$VERSION = '2.22';
 # Don't like depending on externals; this is strong encrytion ... but ...
 require Exporter; require DynaLoader;
 @ISA = qw(Exporter DynaLoader);
@@ -622,7 +622,7 @@ If a travelling employee can carry a session-startup file
 then they are invulnerable to imposter-web-hosts
 trying to feed them trojan JavaScript.
 
-Version 2.21
+Version 2.22
 
 (c) Peter J Billam 1998
 
@@ -722,6 +722,10 @@ variable, and communicate with the server in I<Ajax> style, with
 I<XMLHttpRequest> or I<ActiveXObject>, and I<responseText> or I<responseXML>.
 See the cgi script C<examples/tea_demo.cgi> in the distribution directory.
 
+In the distribution directory there is also C<Tea_JS.js>, which is
+simply the output of C<tea_in_javascript()>.  This could be useful
+if your initial login page is an HTML page rather than a CGI script.
+
 =head1 ROADMAP
 
 Crypt::Tea conflicted with a similarly-named Crypt::TEA by Abhijit Menon-Sen.
@@ -756,7 +760,7 @@ and to Slaven Razic for portability advice in spite of "use bytes".
 =head1 SEE ALSO
 
 examples/tea_demo.cgi, perldoc Encode,
-http://www.pjb.com.au/comp, CGI::Htauth.pm, tea(1), perl(1).
+http://www.pjb.com.au/comp, tea(1), perl(1).
 
 =cut
 
